@@ -12,19 +12,26 @@ class DummyTransport(BaseTransport):
     without obfuscating them.
     """
 
-    def receivedDownstream(self, data, circuit):
+    def __init__(self):
+        """
+        If you override __init__, you ought to call the super method too.
+        """
+
+        super(DummyTransport, self).__init__()
+
+    def receivedDownstream(self, data):
         """
         Got data from downstream; relay them upstream.
         """
 
-        circuit.upstream.write(data.read())
+        self.circuit.upstream.write(data.read())
 
-    def receivedUpstream(self, data, circuit):
+    def receivedUpstream(self, data):
         """
         Got data from upstream; relay them downstream.
         """
 
-        circuit.downstream.write(data.read())
+        self.circuit.downstream.write(data.read())
 
 class DummyClient(DummyTransport):
 
